@@ -50,6 +50,7 @@ static gboolean wl_show_icons = TRUE;
 static gboolean wl_show_ws_names = TRUE;
 static gboolean wl_submenus = FALSE;
 static gboolean wl_sticky_once = FALSE;
+static gboolean wl_add_remove_options = TRUE;
 
 static void
 set_num_workspaces(GtkWidget *w, gpointer data)
@@ -122,7 +123,7 @@ window_destroyed_cb(gpointer data, GObject *where_the_object_was)
 }
 
 static void
-mi_destroyed_cb(GtkObject *object, gpointer user_data)
+mi_destroyed_cb(GtkWidget *object, gpointer user_data)
 {
     g_object_weak_unref(G_OBJECT(user_data),
             (GWeakNotify)window_destroyed_cb, object);
@@ -165,8 +166,8 @@ menu_item_from_wnck_window(WnckWindow *wnck_window, gint icon_width,
     g_free(title);
 
     if(wnck_window_is_active(wnck_window)) {
-        g_string_prepend(label, "<i>");
-        g_string_append(label, "</i>");
+        g_string_prepend(label, "<b><i>");
+        g_string_append(label, "</i></b>");
     }
 
     if(wl_show_icons) {
@@ -219,13 +220,10 @@ windowlist_populate(XfceDesktop *desktop,
     GList *windows, *l;
     WnckWindow *wnck_window;
     gint w, h;
-    PangoFontDescription *italic_font_desc;
     
     if(!show_windowlist)
         return;
     
-    italic_font_desc = pango_font_description_from_string("italic");
-    
     if(gtk_widget_has_screen(GTK_WIDGET(menu)))
         gscreen = gtk_widget_get_screen(GTK_WIDGET(menu));
     else
@@ -280,7 +278,7 @@ windowlist_populate(XfceDesktop *desktop,
             label = gtk_bin_get_child(GTK_BIN(mi));
             gtk_label_set_use_markup(GTK_LABEL(label), TRUE);
             /* center the workspace header */
-            gtk_misc_set_alignment(GTK_MISC(label), 0.4f, 0);
+            gtk_misc_set_alignment(GTK_MISC(label), 0.44f, 0);
             /* If it's not the active workspace, make the color insensitive */
             if(wnck_workspace != active_workspace)
             {
@@ -345,48 +343,48 @@ windowlist_populate(XfceDesktop *desktop,
                     G_CALLBACK(mi_destroyed_cb), wnck_window);
         }
         
-        if(!wl_submenus) {
+        if(!wl_submenus && (i < nworkspaces-1 || wl_add_remove_options)) {
             mi = gtk_separator_menu_item_new();
             gtk_widget_show(mi);
             gtk_menu_shell_append(GTK_MENU_SHELL(submenu), mi);
         }
     }
+
+    if(wl_add_remove_options) {
+        /* 'add workspace' item */
+        if(wl_show_icons) {
+            img = gtk_image_new_from_stock(GTK_STOCK_ADD, GTK_ICON_SIZE_MENU);
+            mi = gtk_image_menu_item_new_with_mnemonic(_("_Add Workspace"));
+            gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(mi), img);
+        } else
+            mi = gtk_menu_item_new_with_mnemonic(_("_Add Workspace"));
+        gtk_widget_show(mi);
+        gtk_menu_shell_append(GTK_MENU_SHELL(menu), mi);
+        g_signal_connect(G_OBJECT(mi), "activate",
+                G_CALLBACK(set_num_workspaces), GINT_TO_POINTER(nworkspaces+1));
     
-    pango_font_description_free(italic_font_desc);
-    
-    /* 'add workspace' item */
-    if(wl_show_icons) {
-        img = gtk_image_new_from_stock(GTK_STOCK_ADD, GTK_ICON_SIZE_MENU);
-        mi = gtk_image_menu_item_new_with_mnemonic(_("_Add Workspace"));
-        gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(mi), img);
-    } else
-        mi = gtk_menu_item_new_with_mnemonic(_("_Add Workspace"));
-    gtk_widget_show(mi);
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu), mi);
-    g_signal_connect(G_OBJECT(mi), "activate",
-            G_CALLBACK(set_num_workspaces), GINT_TO_POINTER(nworkspaces+1));
-    
-    /* 'remove workspace' item */
-    if(!ws_name || atoi(ws_name) == nworkspaces)
-        rm_label = g_strdup_printf(_("_Remove Workspace %d"), nworkspaces);
-    else {
-        gchar *ws_name_esc = g_markup_escape_text(ws_name, strlen(ws_name));
-        rm_label = g_strdup_printf(_("_Remove Workspace '%s'"), ws_name_esc);
-        g_free(ws_name_esc);
+        /* 'remove workspace' item */
+        if(!ws_name || atoi(ws_name) == nworkspaces)
+            rm_label = g_strdup_printf(_("_Remove Workspace %d"), nworkspaces);
+        else {
+            gchar *ws_name_esc = g_markup_escape_text(ws_name, strlen(ws_name));
+            rm_label = g_strdup_printf(_("_Remove Workspace '%s'"), ws_name_esc);
+            g_free(ws_name_esc);
+        }
+        if(wl_show_icons) {
+            img = gtk_image_new_from_stock(GTK_STOCK_REMOVE, GTK_ICON_SIZE_MENU);
+            mi = gtk_image_menu_item_new_with_mnemonic(rm_label);
+            gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(mi), img);
+        } else
+            mi = gtk_menu_item_new_with_mnemonic(rm_label);
+        g_free(rm_label);
+        if(nworkspaces == 1)
+            gtk_widget_set_sensitive(mi, FALSE);
+        gtk_widget_show(mi);
+        gtk_menu_shell_append(GTK_MENU_SHELL(menu), mi);
+        g_signal_connect(G_OBJECT(mi), "activate",
+                G_CALLBACK(set_num_workspaces), GINT_TO_POINTER(nworkspaces-1));
     }
-    if(wl_show_icons) {
-        img = gtk_image_new_from_stock(GTK_STOCK_REMOVE, GTK_ICON_SIZE_MENU);
-        mi = gtk_image_menu_item_new_with_mnemonic(rm_label);
-        gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(mi), img);
-    } else
-        mi = gtk_menu_item_new_with_mnemonic(rm_label);
-    g_free(rm_label);
-    if(nworkspaces == 1)
-        gtk_widget_set_sensitive(mi, FALSE);
-    gtk_widget_show(mi);
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu), mi);
-    g_signal_connect(G_OBJECT(mi), "activate",
-            G_CALLBACK(set_num_workspaces), GINT_TO_POINTER(nworkspaces-1));
 }
 
 static void
@@ -405,6 +403,8 @@ windowlist_settings_changed(XfconfChannel *channel,
         wl_submenus = G_VALUE_TYPE(value) ? g_value_get_boolean(value) : FALSE;
     else if(!strcmp(property, "/windowlist-menu/show-sticky-once"))
         wl_sticky_once = G_VALUE_TYPE(value) ? g_value_get_boolean(value) : FALSE;
+    else if(!strcmp(property, "/windowlist-menu/show-add-remove-workspaces"))
+        wl_add_remove_options = G_VALUE_TYPE(value) ? g_value_get_boolean(value) : TRUE;
 }
 
 void
@@ -431,6 +431,10 @@ windowlist_init(XfconfChannel *channel)
                                                  "/windowlist-menu/show-sticky-once",
                                                  FALSE);
 
+        wl_add_remove_options = xfconf_channel_get_bool(channel,
+                                                        "/windowlist-menu/show-add-remove-workspaces",
+                                                        TRUE);
+
         g_signal_connect(G_OBJECT(channel), "property-changed",
                          G_CALLBACK(windowlist_settings_changed), NULL);
     }
